@@ -1,6 +1,6 @@
 test_that("Can enumerate toy examples", {
   all_toys <- toy_example()
-  expect_is(all_toys, "character")
+  expect_type(all_toys, "character")
   expect_true(all(file.exists(all_toys)))
 
   some_toys <- toy_example(names(all_toys)[1:3])
